@@ -27,6 +27,7 @@ class Connection(object):
         self.log = logging.getLogger(__name__)
         self.verbose = verbose
         self._stop_event = threading.Event()
+        self._stop_event.set()      # stopped until started
         self.socket = None
 
     def _create_socket(self):
@@ -41,13 +42,20 @@ class Connection(object):
     def clear_event(self):
         self._stop_event.clear()
 
+    def set_event(self):
+        self._stop_event.set()
+
     def start(self):
         raise NotImplementedError("%s::start not implemented" % type(self).name)
 
-    def close(self):
-        self.stop()
+    def socket_close(self):
         if self.socket:
             self.socket.close()
             self.socket = None
 
+    def close(self):
+        self.stop()
+        self.socket_close()
+
+
     stopped = is_event_set
